==> camel-jackson-2.14.2-sources.jar: org/apache/camel/component/jackson/ListJacksonDataFormat.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jackson;

import com.fasterxml.jackson.databind.ObjectMapper;

/**
 * A {@link org.apache.camel.component.jackson.JacksonDataFormat} that is using a list
 */
public class ListJacksonDataFormat extends JacksonDataFormat {

    public ListJacksonDataFormat() {
        useList();
    }

    public ListJacksonDataFormat(Class<?> unmarshalType) {
        super(unmarshalType);
        useList();
    }

    public ListJacksonDataFormat(Class<?> unmarshalType, Class<?> jsonView) {
        super(unmarshalType, jsonView);
        useList();
    }

    public ListJacksonDataFormat(ObjectMapper mapper, Class<?> unmarshalType) {
        super(mapper, unmarshalType);
        useList();
    }

    public ListJacksonDataFormat(ObjectMapper mapper, Class<?> unmarshalType, Class<?> jsonView) {
        super(mapper, unmarshalType, jsonView);
        useList();
    }

}

==> camel-jackson-2.23.0-sources.jar: org/apache/camel/component/jackson/ListJacksonDataFormat.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jackson;

import com.fasterxml.jackson.databind.ObjectMapper;

/**
 * A {@link org.apache.camel.component.jackson.JacksonDataFormat} that is using a list
 */
public class ListJacksonDataFormat extends JacksonDataFormat {

    public ListJacksonDataFormat() {
        useList();
    }

    public ListJacksonDataFormat(Class<?> unmarshalType) {
        super(unmarshalType);
        useList();
    }

    public ListJacksonDataFormat(Class<?> unmarshalType, Class<?> jsonView) {
        super(unmarshalType, jsonView);
        useList();
    }
    
    public ListJacksonDataFormat(Class<?> unmarshalType, Class<?> jsonView, boolean enableJaxbAnnotationModule) {
        super(unmarshalType, jsonView, enableJaxbAnnotationModule);
        useList();
    }

    public ListJacksonDataFormat(ObjectMapper mapper, Class<?> unmarshalType) {
        super(mapper, unmarshalType);
        useList();
    }

    public ListJacksonDataFormat(ObjectMapper mapper, Class<?> unmarshalType, Class<?> jsonView) {
        super(mapper, unmarshalType, jsonView);
        useList();
    }

}
